@@ -26,17 +26,18 @@ def _run(module_name="demo", module_type="c", class_name=None):
     else:
         tpl = env.get_template("demo.tpl")
         text = tpl.render({"module_name": module_name})
-    # if IS_WIN:
-    #     text = """#include "stdafx.h"\n{}
-    #     """.format(text)
+    pyd_text = env.get_template("pyd_tool.tpl").render()
     fmt = "{}.{}"
     if module_type in ("cpp", "c++"):
         module_type = "cpp"
     else:
         module_type = "c"
     filename = fmt.format(module_name, module_type)
+    pyd_filename = "pyd_tool.h"
     with open(filename, "w") as f:
         f.write(text)
+    with open(pyd_filename, "w") as f:
+        f.write(pyd_text)
     loader = FileSystemLoader(path)
     env = SandboxedEnvironment(loader=loader)
     tpl = env.get_template("setup.tpl")
@@ -47,7 +48,7 @@ def _run(module_name="demo", module_type="c", class_name=None):
 
 
 def main():
-	parser = argparse.ArgumentParser("Pyd生成工具")
+    parser = argparse.ArgumentParser("Pyd生成工具")
     parser.add_argument("module_name", type=str, help="模块名称")
     parser.add_argument("--module-type", type=str, default="c", choices=["c", "c++", "cpp"], required=False,
                         help="模块类型")
@@ -59,6 +60,7 @@ def main():
     if module_name is None:
         parser.print_help()
     _run(module_name, module_type, class_name)
-    
+
+
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
